@@ -29,12 +29,11 @@ class Parameters:
 
     # ENTORNO POR DEFECTO
     environment = platform.system()
-    environment_configuration = os.getenv('PYBOT_SYSTEM')
+    environment_configuration = "standalone" if os.getenv('PYBOT_SYSTEM') is None else "server"
     environment_record = os.getenv('PYBOT_RECORD')
 
     # CONFIGURACION DE BROWSER Y PRUEBAS
-
-    browser = 'CHROME' if environment_configuration is not None and environment_configuration.lower()=="server" else 'EDGE'
+    browser = 'CHROME' if environment_configuration == "server" else 'EDGE'
     debug = False
     headless = False
 
@@ -50,13 +49,13 @@ class Parameters:
     # CONFIGURACION PATH JMETER
     path_jmeter = f"C:\\Tools\\Jmeter\\bin\\jmeter.bat"
     path_jmeter_libraries_ext = f"C:\\Tools\\Jmeter\\lib\\ext"
-    path_jmeter_downloads = f"{current_path}\\projects\\ApisCliente\\src\\downloads"
+    path_jmeter_downloads = f"{current_path}\\src\\downloads"
     path_jmeter_report_jtl = f"{path_jmeter_downloads}\\report.jtl"
     path_aggregate_report_csv_out = f"{path_jmeter_downloads}\\AggregateReport.csv"
     path_response_over_times_png_out = f"{path_jmeter_downloads}\\ResponseTimesOverTime.png"
     path_response_code_per_second_png_out = f"{path_jmeter_downloads}\\ResponseCodePerSecond.png"
     path_response_threads_state_over_time = f"{path_jmeter_downloads}\\ThreadsStateOverTime.png"
-    path_dashboard = f"{current_path}\\projects\\ApisCliente\\src\\outputs\\dashboard_jmeter"
+    path_dashboard = f"{current_path}src\\outputs\\dashboard_jmeter"
     path_index_html_dashboard = f"{path_dashboard}\\index.html"
 
     # CONFIGURACION TEST DE STRESS Y CARGA
